import{s as a,c as s,a as e,C as t}from"./chunk-SZ463SBG-B6ZQXeQk.js";import{_ as i}from"./mermaid-vendor-DdWbvlft.js";import"./chunk-E2GYISFI-CF8NNeb5.js";import"./chunk-BFAMUDN2-SL2Q4d-_.js";import"./chunk-SKB7J2MH-DyW7x079.js";import"./feature-graph-BoGscR3f.js";import"./react-vendor-DEwriMA6.js";import"./graph-vendor-B-X5JegA.js";import"./ui-vendor-CeCm8EER.js";import"./utils-vendor-BysuhMZA.js";var c={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{c as diagram};
